pyMez.Code.Utils API documentation
Description: Utils is a subpackage designed to provide utility functions and classes to the rest of pyMez or stor...

Top

# pyMez.Code.Utils module

Utils is a subpackage designed to provide utility functions and classes to the rest of pyMez or store one-off helper functions needed in daily development life. All other packages should if needed import this one.

## Help

`pyMez.Code`

Documentation Home | API Documentation Home | Examples | Index

Show source ≡

    """
    Utils is a subpackage designed to provide utility functions and classes to the rest of pyMez or store one-off
    helper functions needed in daily development life. All other packages should if needed import this one.

    Help
    ---------------
    <a href="../index.html">`pyMez.Code`</a>
    <div>
    <a href="../../../pyMez_Documentation.html">Documentation Home</a> |
    <a href="../../index.html">API Documentation Home</a> |
    <a href="../../../Examples/html/Examples_Home.html">Examples</a> |
    <a href="../../../Reference_Index.html">Index </a>
    </div>
    """

## Sub-modules

pyMez.Code.Utils.Alias

Module that defines functions for handling alias definitions in Classes

## Help

`pyMez.Code.Utils`

Documentation Home | API Documentation Home | <a href="../../../Examples/ht...

pyMez.Code.Utils.DistributionUtils

Tools to help distribution. This began by renaming all instances of pyMeasure to pyMez to avoid PYPI conflicts with another package. Procedure: + update the src folder + update the setup.py file to contain at least a higher number of version + run this module to add init to all of the directori...

pyMez.Code.Utils.DjangoUtils

DjangoUtils contains helper functions and classes to create django websites using meta-scripting tools

## Help

`pyMez.Code.Utils`

Documentation Home | API Documentation Home</...

pyMez.Code.Utils.GetMetadata

This module gets metadata on files from the filesystem (Windows only) or the file itself.

## Help

`pyMez.Code.Utils`

Documentation Home | API Documentation Home | <a href=".....

pyMez.Code.Utils.HPBasicUtils

This module handles HPBasic code when it has already been converted to .txt (DOS ASCII). To convert from native format to DOS ASCII, install HPBasic, Run HP Basic and type: CONFIGURE SAVE ASCII OFF Then LOAD "My_File" SAVE "My_ASCII_File"

    Help

`py...

pyMez.Code.Utils.HelpUtils

The HelpUtils module has tools for interacting with help files. It uses pdoc for auto-generated help and nbcovert to change ipynb based examples to html. There is an error when certain extensions are activated in jupyter for nbconvert that is solved by changing the imports in three modules s...

pyMez.Code.Utils.Names

The module names contains the functions for automatically generating file names

## Help

`pyMez.Code.Utils`

Documentation Home | API Documentation Home | <a href="../../../...

pyMez.Code.Utils.PerformanceUtils

PerformanceUtils contains functions and classes for testing the performance of code in pyMez

## Help

`pyMez.Code.Utils`

Documentation Home | API Documentation Home | <a h...

pyMez.Code.Utils.Types

Types contains type definitions to fix python 2->3 migration issues

## Help

`pyMez.Code.Utils`

Documentation Home | API Documentation Home | <a href="../../../Examples/htm...

pyMez.Code.Utils.pyMezUnitTest

pyMezUnitTests Runs a series of unit tests on the modules in pyMez, before adding a module to the library add a unit test and check that all the others pass. All modules should be imported using import full.module.name and test classes should be named TestPyMeasureModuleName to prevent confusion ...